@@ -1,11 +1,11 @@
 import fnmatch
 import os
 
-from jinja2 import Template, StrictUndefined
+from jinja2 import Template, StrictUndefined, UndefinedError, Environment, meta
 
-from conans.errors import ConanException
+from conan.errors import ConanException
 from conans.util.files import load
-from conans import __version__
+from conan import __version__
 
 
 class NewAPI:
@@ -26,9 +26,12 @@ class NewAPI:
         from conan.internal.api.new.msbuild_exe import msbuild_exe_files
         from conan.internal.api.new.bazel_lib import bazel_lib_files
         from conan.internal.api.new.bazel_exe import bazel_exe_files
+        from conan.internal.api.new.bazel_7_lib import bazel_lib_files_7
+        from conan.internal.api.new.bazel_7_exe import bazel_exe_files_7
         from conan.internal.api.new.autotools_lib import autotools_lib_files
         from conan.internal.api.new.autoools_exe import autotools_exe_files
         from conan.internal.api.new.local_recipes_index import local_recipes_index_files
+        from conan.internal.api.new.qbs_lib import qbs_lib_files
         new_templates = {"basic": basic_file,
                          "cmake_lib": cmake_lib_files,
                          "cmake_exe": cmake_exe_files,
@@ -36,12 +39,16 @@ class NewAPI:
                          "meson_exe": meson_exe_files,
                          "msbuild_lib": msbuild_lib_files,
                          "msbuild_exe": msbuild_exe_files,
+                         # TODO: Rename xxx_7 to xxx when dropped Bazel 6.x compatibility
                          "bazel_lib": bazel_lib_files,
                          "bazel_exe": bazel_exe_files,
+                         "bazel_7_lib": bazel_lib_files_7,
+                         "bazel_7_exe": bazel_exe_files_7,
                          "autotools_lib": autotools_lib_files,
                          "autotools_exe": autotools_exe_files,
                          "alias": alias_file,
-                         "local_recipes_index": local_recipes_index_files}
+                         "local_recipes_index": local_recipes_index_files,
+                         "qbs_lib": qbs_lib_files}
         template_files = new_templates.get(template_name)
         return template_files
 
@@ -86,9 +93,11 @@ class NewAPI:
     @staticmethod
     def render(template_files, definitions):
         result = {}
-        name = definitions.get("name", "Pkg")
+        name = definitions.get("name", "pkg")
         if isinstance(name, list):
             raise ConanException(f"name argument can't be multiple: {name}")
+        if name != name.lower():
+            raise ConanException(f"name argument must be lowercase: {name}")
         definitions["conan_version"] = __version__
 
         def ensure_list(key):
@@ -111,11 +120,35 @@ class NewAPI:
         definitions["package_name"] = as_package_name(name)
         definitions["as_name"] = as_name
         definitions["names"] = lambda x: ", ".join(r.split("/", 1)[0] for r in x)
-        for k, v in template_files.items():
-            k = Template(k, keep_trailing_newline=True, undefined=StrictUndefined).render(
-                **definitions)
-            v = Template(v, keep_trailing_newline=True, undefined=StrictUndefined).render(
-                **definitions)
-            if v:
-                result[k] = v
+        if "name" not in definitions:
+            definitions["name"] = "mypkg"
+        if "version" not in definitions:
+            definitions["version"] = "0.1"
+        version = definitions.get("version")
+        if isinstance(version, list):
+            raise ConanException(f"version argument can't be multiple: {version}")
+
+        try:
+            for k, v in template_files.items():
+                k = Template(k, keep_trailing_newline=True, undefined=StrictUndefined).render(
+                    **definitions)
+                v = Template(v, keep_trailing_newline=True, undefined=StrictUndefined).render(
+                    **definitions)
+                if v:
+                    result[k] = v
+        except UndefinedError:
+            template_vars = []
+            for templ_str in template_files.values():
+                env = Environment()
+                ast = env.parse(templ_str)
+                template_vars.extend(meta.find_undeclared_variables(ast))
+
+            injected_vars = {"conan_version", "package_name", "as_name"}
+            optional_vars = {"requires", "tool_requires", "output_root_dir"}
+            template_vars = list(set(template_vars) - injected_vars - optional_vars)
+            template_vars.sort()
+
+            raise ConanException("Missing definitions for the template. "
+                                 "Required definitions are: {}"
+                                 .format(", ".join("'{}'".format(var) for var in template_vars)))
         return result
