@@ -1,6 +1,6 @@
 from collections import OrderedDict
 
-from conans.errors import ConanException
+from conan.errors import ConanException
 from conans.model.pkg_type import PackageType
 from conans.model.recipe_ref import RecipeReference
 from conans.model.version_range import VersionRange
@@ -36,6 +36,7 @@ class Requirement:
         self.override_ref = None  # to store if the requirement has been overriden (store new ref)
         self.is_test = test  # to store that it was a test, even if used as regular requires too
         self.skip = False
+        self.required_nodes = set()  # store which intermediate nodes are required, to compute "Skip"
 
     @property
     def files(self):  # require needs some files in dependency package
@@ -254,7 +255,13 @@ class Requirement:
         self.transitive_libs = self.transitive_libs or other.transitive_libs
         if not other.test:
             self.test = False  # it it was previously a test, but also required by non-test
-        # TODO: self.package_id_mode => Choose more restrictive?
+        # necessary even if no propagation, order of requires matter
+        self.is_test = self.is_test or other.is_test
+        # package_id_mode is not being propagated downstream. So it is enough to check if the
+        # current require already defined it or not
+        if self.package_id_mode is None:
+            self.package_id_mode = other.package_id_mode
+        self.required_nodes.update(other.required_nodes)
 
     def transform_downstream(self, pkg_type, require, dep_pkg_type):
         """
